/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 * 
 */

/**
  * Implementations and examples of the <b>Factory Method</b> 
  * design pattern [<a href="http://www.rode.dk/thesis/Bibliography.htm#Gamma95" target="thesis-bibliography">Gamma95</a>, p.107]. <p>
  *  
  * <b>Intent</b>:<ul><p><i>
  * 
  *    Define an interface for creating an object, but let subclasses 
  *    decide which class to instantiate. Factory Method lets a class 
  *    defer instantiation to subclasses.
  *    
  * </i></ul>
  * 
  * Here, the {@link dk.rode.thesis.command.Command} interface 
  * represents the <b>Product</b> participant, and a concrete 
  * {@code Command} implementation represent the <b>ConcreteParticipant</b>
  * participant, for example {@link dk.rode.thesis.command.NextCommand}. 
  * Hence, factory methods are defined to create commands. As explained in 
  * the {@linkplain dk.rode.thesis.command Command} pattern, the commands 
  * primarily use {@link dk.rode.thesis.meta.model.Sequence} instances 
  * as <i>receivers</i>, but some are receiver-less. <p> 
  * 
  * The {@link dk.rode.thesis.factorymethod.CommandCreator} 
  * type represents the <b>Creator</b> participant, and a sub-class of it 
  * represent a <b>ConcreteCreator</b>, for example 
  * {@link dk.rode.thesis.factorymethod.ReversibleSequenceCommandCreator}. 
  * The {@code CommandCreater<E,T>} class is parameterised with
  * the type of the {@code Command} (and {@code Sequence}) values as
  * well the type of <i>tokens</i> used identify the type of commands
  * to create. The {@code ReversibleSequenceCommandCreator}, and others,
  * use internal sequence {@link dk.rode.thesis.meta.model.Sequence.State states}
  * as tokens, while the {@link dk.rode.thesis.factorymethod.ReflectiveCommandCreator}
  * class uses {@link dk.rode.thesis.meta.reflect.TypeLiteral type literals}
  * as tokens. <p>
  * 
  * Furthermore, the generic {@link dk.rode.thesis.factorymethod.Factory} class 
  * illustrates how reflection can be used to make a completely generic factory type 
  * to create any type of instantiable product, providing the product type has a 
  * usable constructor. <p>
  * 
  * <a name="uml"></a><b>UML Class Diagram</b>:<br>
  * <img src="doc-files/FactoryMethod.png" border="0"><p>
  * 
  * <b>Implementation notes</b>:<br/>
  * The {@link dk.rode.thesis.meta.log.LogManager log} implementation 
  * used in this thesis also illustrates the Factory Method pattern. 
  * 
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a> 
  */
@Pattern(name         = "Factory Method", 
         scope        = Scope.Class,
         purpose      = Purpose.Creational,
         participants = {"Product", "ConcreteProduct", "Creator", "ConcreteCreator"})
package dk.rode.thesis.factorymethod;

import dk.rode.thesis.meta.Pattern;
import dk.rode.thesis.meta.Purpose;
import dk.rode.thesis.meta.Scope;

