/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 *
 */
package dk.rode.thesis.flyweight;

import dk.rode.thesis.meta.Participant;

/**
  * A <i>symbol</i> represents a single symbol that
  * is not a {@link Whitespace whitespace} or a {@link Letter letter}. <p>
  * 
  * Digits are also considered symbols.
  *  
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  */
@Participant("ConcreteFlyweight")
public class Symbol extends AbstractCharacter {

    /**
      * The actual shared symbol. 
      */
    private final char symbol;

    /**
      * Constructor.
      * 
      * @param symbol
      */
    Symbol(char symbol) {
        super();
        this.symbol = symbol;
    }

    /**
      * 
      */
    public final char charAt(int index) {
        // To maintain semantics...
        if (index != 0) {
            throw new IndexOutOfBoundsException(Integer.toString(index));
        }
        return this.symbol;
    }

    /**
      * 
      */
    public final int length() {
        return 1;
    }

    /**
      * 
      */
    public final CharSequence subSequence(int start, int end) {
        // To maintain semantics...
        return java.lang.Character.toString(this.symbol).subSequence(start, end);
    }

    /**
      * 
      */
    public final String toString() {
        return java.lang.Character.toString(this.symbol);
    }
    
    /**
      * 
      */
    public final int compareTo(Character character) {
        return this.toString().compareTo(character.toString());
    }

}
