/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 *
 */
package dk.rode.thesis.interpreter;

import static dk.rode.thesis.meta.util.Const.SERIAL_VERSION_UID;

/**
  * An <i>expression exception</i> is thrown in case of context,
  * evaluation, or expression errors. 
  *
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  */
public class ExpressionException extends Exception {

    /**
      * Serial version id. 
      */
    final static long serialVersionUID = SERIAL_VERSION_UID;
    
    /**
      * No-arg constructor.
      */
    public ExpressionException() {
        super();
    }

    /**
      * Constructor.
      * 
      * @param expression The faulting expression; can be null.
      */
    public ExpressionException(Expression<?> expression) {
        this(expression == null ? null : expression.toString());
    }

    /**
      * Constructor.
      * 
      * @param message The detail message; can be null.
      */
    public ExpressionException(String message) {
        super(message);
    }

    /**
      * Constructor.
      * 
      * @param cause The causing throwable; can be null.
      */
    public ExpressionException(Throwable cause) {
        super(cause);
    }

}
