/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 * 
 */
package dk.rode.thesis.meta;

import static java.lang.annotation.ElementType.PACKAGE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
  * Annotation encompassing an entire <b>pattern</b>, declared within
  * a given package <p>
  * 
  * The actual usage of pattern participants are 
  * specified by the {@link Participant} and 
  * {@link ParticipantUsage} annotations. 
  *
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  */
@Documented
@Retention(RUNTIME)
@Target(PACKAGE)
public @interface Pattern {

    /**
      * The name of this pattern.
      */
    String name();
    
    /**
      * The scope(s) of this pattern.
      */
    Scope[] scope();
    
    /**
      * The purpose of this pattern.
      */
    Purpose purpose();
    
    /**
      * The participants in this pattern.
      * 
      * @see Participant
      * @see ParticipantUsage
      */
    String[] participants();
        
}
