/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 * 
 */
package dk.rode.thesis.meta.model;

/**
  * An <i>alphabet sequence</i> for letters in the English alphabet:
  * {@code a} though {@code z}, lower-cased. 
  *  
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  */
public class EnglishAlphabetSequence extends ArraySequence<String> {

    /**
      * The letters in the English alphabet. 
      */
    private final static String[] alphabet = { 
        "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", 
        "n", "o", "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z"
    };
    
    /**
      * No-arg constructor.
      */
    public EnglishAlphabetSequence() {
        super(alphabet);
    }

    /**
      * Copy constructor. <p>
      * 
      * This sequence starts at the current index of {@code sequence}.
      * 
      * @param  sequence The sequence to copy; cannot be null.
      * @throws NullPointerException If {@code sequence} is null.
      */
    public EnglishAlphabetSequence(EnglishAlphabetSequence sequence) {
        super(sequence);
    }
    
    /**
      * 
      */
    public EnglishAlphabetSequence copy() {
        return new EnglishAlphabetSequence(this);
    }
    
}
