/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 * 
 */
package dk.rode.thesis.meta.test;

import dk.rode.thesis.meta.log.Log;
import dk.rode.thesis.meta.log.LogFactory;
import dk.rode.thesis.meta.util.Arguments;

/**
  * Executes <b>all</b> individual pattern tests.
  * 
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  */
public class AllTests implements Testable {

    /**
      * Executes <b>all</b> individual pattern tests.
      * 
      * @param  args The arguments to supply to {@link #test(Log, Arguments)},
      *              if any; can be null.
      */
    public static void main(String[] args) {
        new AllTests().test(LogFactory.getLog(), new Arguments(args));
    }
    
    /**
      * 
      */
    public boolean test(Log out, Arguments arguments) {
        out.heading("Testing all...");
        
        boolean ok = true;
        
        Testable[] tests = {
           new dk.rode.thesis.abstractfactory.Main(),
           new dk.rode.thesis.adapter.Main(),
           new dk.rode.thesis.bridge.Main(),
           new dk.rode.thesis.builder.Main(),
           new dk.rode.thesis.chainofresponsibility.Main(),
           new dk.rode.thesis.command.Main(),
           new dk.rode.thesis.composite.Main(),
           new dk.rode.thesis.decorator.Main(),
           new dk.rode.thesis.facade.Main(),
           new dk.rode.thesis.factorymethod.Main(),
           new dk.rode.thesis.flyweight.Main(),
           new dk.rode.thesis.interpreter.Main(),
           new dk.rode.thesis.iterator.Main(),
           new dk.rode.thesis.mediator.Main(),
           new dk.rode.thesis.memento.Main(),
           new dk.rode.thesis.observer.Main(),
           new dk.rode.thesis.prototype.Main(),
           new dk.rode.thesis.proxy.Main(),
           new dk.rode.thesis.singleton.Main(),
           new dk.rode.thesis.state.Main(),
           new dk.rode.thesis.strategy.Main(),
           new dk.rode.thesis.templatemethod.Main(),
           new dk.rode.thesis.visitor.Main(),
        };

        for (Testable test : tests) {
            try {
                ok = test.test(out, arguments) && ok;
            } catch (Exception e) {
                out.error("Test failed: ", test.getClass().getName()).error(e);
                ok = false;
            }
        }
        
        out.heading("Testing all ", ok ? "succeeded" : "failed", "!");
        
        return ok;
    }
        
}
