/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 *
 */
package dk.rode.thesis.meta.util;

/**
  * An <i>error handler</i> can decide whether or not a given
  * type of error is manageable or not using the 
  * {@link #handle(Throwable)} method. If manageable, true
  * will be returned, otherwise false. <p>  
  *
  * <b>Implementation notes</b>:<br>
  * This is an application of the {@linkplain dk.rode.thesis.strategy Strategy}
  * pattern, to be used in object composition.
  * 
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  */
public interface ErrorHandler {

    /**
      * Returns true if {@code throwable} can be managed by this
      * error handler, false if not.
      * 
      * @param  throwable The error; can be null, in which case true
      *                   is returned.
      * @return True if {@code throwable} can be managed by this
      *         error handler, false if not.                   
      */
    public boolean handle(Throwable throwable);
    
}
