/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 *
 */
package dk.rode.thesis.observer;

import dk.rode.thesis.meta.Participant;
import dk.rode.thesis.meta.model.Sequence;

/**
  * A <i>sequence observer</i> is an object that is 
  * {@link #sequenceEvent(Sequence, Object) notified} 
  * when the {@link ObservableSequence observable} sequence 
  * it is attached to changes its <i>aspect</i> value. <p>
  * 
  * <b>Implementation notes</b>:<br>
  * Sequence observers do not employ parameterised types on
  * the sequence supplied to the notification method because the 
  * same observer may be attached to several different types 
  * of observable sequences. <p>
  * 
  * Furthermore, the actual type of sequence supplied to the
  * notification method <b>cannot</b> be assumed
  * {@link ObservableSequence observable}, or even of the type
  * of sequence this observer was attached to; it might be adapted, 
  * decorated, composite, or proxied. Hence, several other patterns
  * may be applied in the implementation of this interface.
  *
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  * 
  * @param  <A> The type of aspect used by this observer.
  */
@Participant("Observer")
public interface SequenceObserver<A> {

    /**
      * Notification method that is invoked when the 
      * {@link Sequence sequence} supplied as {@code sequence} 
      * has changed its state to {@code state}. <p>
      * 
      * The type of sequence is not defined; it cannot be assumed
      * {@link ObservableSequence observable}, or even of the type
      * this observer was attached to; it might be adapted, decorated, 
      * composite, or proxied. <p>
      * 
      * @param  sequence This sequence; cannot be null.
      * @param  aspect   The current (new) aspect; cannot be null.
      * @throws NullPointerException If {@code sequence} is null. Nullability
      *         of {@code aspect} is implementation dependent.
      */
    public void sequenceEvent(Sequence<?> sequence, A aspect);
        
}
