/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 * 
 */

/**
  * Implementations and examples of the <b>Strategy</b> 
  * design pattern [<a href="http://www.rode.dk/thesis/Bibliography.htm#Gamma95" target="thesis-bibliography">Gamma95</a>, p.315]. <p>
  * 
  * <b>Intent</b>:<ul><p><i>
  * 
  *    Define a family of algorithms, encapsulate each
  *    one, and make them interchangeable. Strategy lets the algorithm 
  *    vary independently from clients that use it.
  * 
  * </i></ul>
  * 
  * Here, the <b>Strategy</b> participant is represented by the
  * {@link dk.rode.thesis.strategy.StringablePolicy} 
  * interface that allows the <b>Context</b> participant in form
  * of {@link dk.rode.thesis.strategy.Stringable} objects
  * to have numerous different textual representations. As 
  * {@link dk.rode.thesis.meta.model.Sequence} implements
  * the {@code Stringable} interface, any sequence implementation
  * is thus a representation of the <b>Context</b> participant. <p>
  * 
  * The enumerations {@link dk.rode.thesis.strategy.ObjectPolicy}
  * and {@link dk.rode.thesis.strategy.SequencePolicy} represent
  * the <b>ConcreteStrategy</b> participant, each defining many different
  * policies (strategies) for formatting {@code Object} and 
  * {@link dk.rode.thesis.meta.model.Sequence} instances,
  * respectively. <p>   
  * 
  * <a name="uml"></a><b>UML Class Diagram</b>:<p>
  * <img src="doc-files/Strategy.png" border="0"><p>
  * 
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a> 
  */
@Pattern(name         = "Strategy", 
         scope        = Scope.Object,
         purpose      = Purpose.Behavioural,
         participants = {"Strategy", "ConcreteStrategy", "Context"})
package dk.rode.thesis.strategy;

import dk.rode.thesis.meta.Pattern;
import dk.rode.thesis.meta.Purpose;
import dk.rode.thesis.meta.Scope;

