/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 * 
 */

/**
  * Implementations and examples of the <b>Template Method</b> 
  * design pattern [<a href="http://www.rode.dk/thesis/Bibliography.htm#Gamma95" target="thesis-bibliography">Gamma95</a>, p.325]. <p>
  * 
  * <b>Intent</b>:<ul><p><i>
  * 
  *    Define the skeleton of an algorithm in an operation, deferring some 
  *    steps to subclasses. Template Method lets subclasses redefine
  *    certain steps of an algorithm without changing the algorithm's structure.
  * 
  * </i></ul>
  * 
  * Here, the <b>AbstractClass</b> participant is represented by the
  * {@link dk.rode.thesis.templatemethod.SequenceTemplate}
  * class. It allows the creation of sequence values to be considered
  * as a <i>multi-step process</i> like <i>open-value</i>, <i>get-value</i>,
  * and <i>close-value</i>. <p>
  * 
  * The <b>ConcreteClass</b> participant is represented by the actual 
  * sub-classes of the abstract class participant, namely 
  * {@link dk.rode.thesis.templatemethod.NegativeSequence}, 
  * {@link dk.rode.thesis.templatemethod.FileSequence}, and 
  * {@link dk.rode.thesis.templatemethod.ZipSequence}. <p> 
  * 
  * <a name="uml"></a><b>UML Class Diagram</b>:<p>
  * <img src="doc-files/TemplateMethod.png" border="0"><p>
  * 
  * <b>Implementation notes</b>:<br/>
  * Java does not support functional multiple inheritance. Hence, any
  * concrete class can at most inherit functionality from one abstract
  * class. An alternative is to define the required template methods
  * in a single interface. The abstract and concrete classes can implement
  * this interface, but the actual implementation can be a component
  * which is used through composition in the concrete class. This approach
  * can also be combined with inheritance.  
  * 
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a> 
  */
@Pattern(name         = "Template Method", 
         scope        = Scope.Class,
         purpose      = Purpose.Behavioural,
         participants = {"AbstractClass", "ConcreteClass"})
package dk.rode.thesis.templatemethod;

import dk.rode.thesis.meta.Pattern;
import dk.rode.thesis.meta.Purpose;
import dk.rode.thesis.meta.Scope;

