/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 *
 */
package dk.rode.thesis.visitor;

import dk.rode.thesis.composite.CompositeSequence;
import dk.rode.thesis.meta.Participant;
import dk.rode.thesis.meta.model.Sequence;

/**
  * A <i>sequence type scanner</i> performs the actual traversal
  * of the {@link Sequence sequence} structure to be visited
  * by a {@link SequenceTypeVisitor type} visitor, invoking the
  * {@link TypeVisitableSequence#accept(SequenceTypeVisitor, Object)} 
  * visitation method on each found {@link TypeVisitableSequence type}
  * visitable sequence. <p>
  * 
  * Non-visitable sequences are ignored, but ordinary 
  * {@link CompositeSequence composite} sequences are still traversed.  
  * 
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  * 
  * @see    SequenceTypeVisitor
  * @see    SequenceValueScanner
  */
@Participant("ObjectStructure")
public interface SequenceTypeScanner {

    /**
      * Performs the traversal of the sequence structure starting 
      * with {@code sequence} using the {@link SequenceTypeVisitor type}
      * visitor supplied as {@code visitor}. If {@code sequence}
      * is non-composite, it will be the only sequence visited. <p>
      * 
      * For each {@link TypeVisitableSequence type} visitable sequence
      * found in the sequence structure, the  
      * {@link TypeVisitableSequence#accept(SequenceTypeVisitor, Object)} 
      * visitation method is invoked. <p>
      *   
      * @param <P>       The type of the additional parameter to required by
      *                  {@code visitor}. Use {@code Void} for visitors that 
      *                  do not need an additional parameter.
      * @param  sequence The starting sequence ("root"); cannot be null.
      * @param  visitor  The type visitor to use; cannot be null.
      * @param  argument A {@code visitor} specified argument, if any; 
      *                  nullability determined by {@code visitor}.
      * @throws NullPointerException If {@code sequence} or {@code visitor}
      *         are null.
      */
    public <P> void scan(TypeVisitableSequence<?> sequence, SequenceTypeVisitor<P> visitor, P argument);
    
}
