/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 *
 */
package dk.rode.thesis.visitor;

import dk.rode.thesis.meta.Participant;
import dk.rode.thesis.meta.model.Sequence;

/**
  * A <i>sequence visitor</i> is the super type for all visitors that
  * can visit a {@link Sequence sequence} type. <p>
  *
  * This interface only declares a single method, namely
  * {@link #visitUnknown(Sequence, Object)}, which is the default
  * visitation method to use in case a visitation cannot be performed. 
  * Actual sub-classes must thus supply the actual <i>meaningful</i> 
  * visitation methods.
  *  
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  * 
  * @see    SequenceValueVisitor
  * @see    SequenceTypeVisitor
  * 
  * @param <P> The type of the additional parameter to this visitor's methods.
  *            Use {@code Void} for visitors that do not need an additional 
  *            parameter.
  */
@Participant("Visitor")
public interface SequenceVisitor<P> {
        
    /**
      * Visits a {@link Sequence sequence} that cannot be visited
      * by any other visitation methods declared by this visitor.
      *  
      * @param  sequence The sequence to visit; never null.
      * @param  argument A visitor-specified argument, if any; nullability
      *                  determined by the visitor implementation.
      */
    public void visitUnknown(Sequence<?> sequence, P argument);
    
}
