/*
 * Created: May-August, 2007
 *
 * Evaluating Software Design Patterns
 * - the "Gang of Four" patterns implemented in Java 6
 *
 * Gunni Rode - http://www.rode.dk 
 *
 * Master's Thesis, Computer Science
 * Department of Computer Science,
 * The Faculty of Science,
 * University of Copenhagen
 * 
 * Feel free to use and/or modify the Java 6 source code 
 * developed for this thesis AT YOUR OWN RISK, but note 
 * that the source code comes WITHOUT ANY - and I do mean 
 * WITHOUT ANY - form of warranty WHAT SO EVER!
 *
 * The original thesis and source code are available at 
 * http://www.rode.dk/thesis
 *
 */
package dk.rode.thesis.visitor;

import dk.rode.thesis.meta.Participant;
import dk.rode.thesis.meta.model.LongSequence;
import dk.rode.thesis.meta.model.Sequence;

/**
  * A <i>visitable long sequence</i> is a {@link LongSequence} that is
  * {@link ValueVisitableSequence value} visitable using the 
  * {@link SequenceValueVisitor#visitLongValued(Sequence, Object)}
  * visitation method <b>and</b> is {@link ValueVisitableSequence type}
  * visitable as well. <p>
  * 
  * This sequence adds no additional state to a long sequence, only 
  * visitation behaviour.
  *
  * @author Gunni Rode / <a href="http://www.rode.dk">rode.dk</a>
  */
@Participant("ConcreteElement")
public class VisitableLongSequence 
     extends LongSequence 
  implements ValueVisitableSequence<Long>, TypeVisitableSequence<Long> {
    
    /**
      * No-arg constructor.
      */
    public VisitableLongSequence() {
        super();
    }

    /**
      * Constructor.
      * 
      * @param start The start value of this sequence.
      */
    public VisitableLongSequence(long start) {
        super(start);
    }

    /**
      * Copy constructor.
      * 
      * @param  sequence The sequence to copy; cannot be null.
      * @throws NullPointerException If {@code sequence} is null.
      */
    public VisitableLongSequence(LongSequence sequence) {
        // ok to copy super class since we add no additional state, behaviour only...
        super(sequence);
    }
    
    /**
      * 
      */
    public VisitableLongSequence copy() {
        return new VisitableLongSequence(this);
    }

    /**
      * @see SequenceValueVisitor#visitLongValued(Sequence, Object) 
      */
    public <P> void accept(SequenceValueVisitor<P> visitor, P argument) {
        visitor.visitLongValued(this, argument);
    }

    /**
      * @see SequenceTypeVisitor#visitUnknown(Sequence, Object) 
      */
    public <P> void accept(SequenceTypeVisitor<P> visitor, P argument) {
        visitor.visitUnknown(this, argument);
    }
    
}
